#
# spec file for package qbs
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2018 The Qt Company.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt5_version 5.11.0
Name:           qbs
Version:        1.16.0
Release:        bp153.1.16
Summary:        Modern build tool for software projects
# Legal:
# scripts/ is LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
# share/ is LGPL-2.1-only OR LGPL-3.0-only WITH Qt-LGPL-exception-1.1.
# src/ is a mix of both licenses combo...except transformerchangetracking.{cpp,h}
# which is GPL-3.0-only WITH Qt-GPL-exception-1.0
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later) AND (LGPL-2.1-only OR LGPL-3.0-only WITH Qt-LGPL-exception-1.1) AND GPL-3.0-only WITH Qt-GPL-exception-1.0
Group:          Development/Tools/Building
URL:            https://wiki.qt.io/Qbs
Source:         https://download.qt.io/official_releases/%{name}/%{version}/%{name}-src-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  libQt5Concurrent-devel >= %{qt5_version}
BuildRequires:  libQt5Core-devel >= %{qt5_version}
BuildRequires:  libQt5Core-private-headers-devel >= %{qt5_version}
BuildRequires:  libQt5Gui-devel >= %{qt5_version}
BuildRequires:  libQt5Network-devel >= %{qt5_version}
BuildRequires:  libQt5Script-devel >= %{qt5_version}
BuildRequires:  libQt5Test-devel >= %{qt5_version}
BuildRequires:  libQt5Widgets-devel >= %{qt5_version}
BuildRequires:  libQt5Xml-devel >= %{qt5_version}
# Qt Creator used to package qbs too
Conflicts:      libqt5-creator <= 4.5.0

%description
Qbs is a tool that helps simplify the build process for developing projects
across multiple platforms. Qbs can be used for any software project, whether
it is written with Qt or not.

Qbs is an all-in one tool that generates a build graph from a high-level
project description (like qmake or CMake) and additionally undertakes the tasks
of executing the commands in the low-level build graph (like make).

This package contains the command line interface. The Qt Creator IDE does
directly support working qbs projects.

%package devel
Summary:        Development files for %{name}
Group:          Development/Tools/Building
Requires:       %{name} = %{version}-%{release}

%description devel
This package is required to develop applications using %{name} as a library

%prep
%setup -q -n %{name}-src-%{version}

%build
makeopts=""

# QBS_LIBEXEC_DESTDIR, QBS_RELATIVE_LIBEXEC_PATH need to be
# set because the defaults are hardcoded to 'libexec'
#
# qbs_enable_project_file_updates allow to build Qt Creator
# against the installed qbs.
%qmake5 %{name}.pro -r QBS_INSTALL_PREFIX=%{_prefix} \
    QBS_LIBRARY_DIRNAME=%{_lib} \
    QBS_LIBEXEC_DESTDIR=../../../lib/%{name} \
    QBS_LIBEXEC_INSTALL_DIR=%{_libexecdir}/%{name} \
    QBS_RELATIVE_LIBEXEC_PATH=../lib/%{name} \
    QBS_LIB_INSTALL_DIR=%{_libdir} \
    QBS_PLUGINS_INSTALL_DIR=%{_libdir} \
    CONFIG+=qbs_enable_project_file_updates

%make_build $makeopts

%install
%qmake5_install

# Cleanup
rm -f %{buildroot}%{_datadir}/%{name}/python/biplist/qt_attribution.json
rm -f %{buildroot}%{_datadir}/%{name}/python/dmgbuild/qt_attribution.json
rm -f %{buildroot}%{_datadir}/%{name}/python/ds_store/qt_attribution.json
rm -f %{buildroot}%{_datadir}/%{name}/python/mac_alias/qt_attribution.json

ln -f -s qbs.1.gz %{buildroot}/%{_mandir}/man1/qbs-config.1.gz
ln -f -s qbs.1.gz %{buildroot}/%{_mandir}/man1/qbs-config-ui.1.gz
ln -f -s qbs.1.gz %{buildroot}/%{_mandir}/man1/qbs-create-project.1.gz
ln -f -s qbs.1.gz %{buildroot}/%{_mandir}/man1/qbs-setup-android.1.gz
ln -f -s qbs.1.gz %{buildroot}/%{_mandir}/man1/qbs-setup-qt.1.gz
ln -f -s qbs.1.gz %{buildroot}/%{_mandir}/man1/qbs-setup-toolchains.1.gz

%fdupes %{buildroot}%{_datadir}/%{name}

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license LGPL_EXCEPTION.txt LICENSE.LGPLv21 LICENSE.LGPLv3 LICENSE.GPL3-EXCEPT
%doc README.md changelogs/changes-%{version}.md
%dir %{_datadir}/%{name}/
%dir %{_libdir}/%{name}/
%dir %{_libdir}/%{name}/plugins/
%dir %{_libexecdir}/%{name}/
%{_bindir}/%{name}-config
%{_bindir}/%{name}-config-ui
%{_bindir}/%{name}-create-project
%{_bindir}/%{name}-setup-android
%{_bindir}/%{name}-setup-qt
%{_bindir}/%{name}-setup-toolchains
%{_bindir}/qbs
%{_datadir}/%{name}/imports/
%{_datadir}/%{name}/module-providers/
%{_datadir}/%{name}/modules/
%{_datadir}/%{name}/python/
%{_datadir}/%{name}/qml-type-descriptions/
%{_libdir}/%{name}/plugins/lib%{name}_cpp_scanner.so
%{_libdir}/%{name}/plugins/lib%{name}_qt_scanner.so
%{_libdir}/%{name}/plugins/libclangcompilationdbgenerator.so
%{_libdir}/%{name}/plugins/libiarewgenerator.so
%{_libdir}/%{name}/plugins/libkeiluvgenerator.so
%{_libdir}/%{name}/plugins/libmakefilegenerator.so
%{_libdir}/%{name}/plugins/libvisualstudiogenerator.so
%{_libdir}/lib%{name}*.so.*
%{_libexecdir}/%{name}/%{name}_processlauncher
%{_libexecdir}/%{name}/dmgbuild
%{_mandir}/man1/qbs*%{ext_man}

%files devel
%license LGPL_EXCEPTION.txt LICENSE.LGPLv21 LICENSE.LGPLv3 LICENSE.GPL3-EXCEPT
%doc %{_datadir}/%{name}/examples/
%{_includedir}/%{name}/
%{_libdir}/lib%{name}*.prl
%{_libdir}/lib%{name}*.so

%changelog
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.16.0. Check the changes-1.16.0.md file for the
  complete changelog.
  * List properties in modules are now merged according to
    inter-module dependencies.
  * The clang-cl toolchain module got more features and flexibility.
  * Improved support for recent Qt versions
  * A new ConanfileProbe allows better and more flexible
    integration of Qbs and the Conan package manager.
* Thu Dec 26 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.15.0. Check the changes-1.15.0.md file for the complete changelog.
  * Added a timeout property to Command, JavaScriptCommand and AutotestRunner.
  * Linker map files can be generated with all toolchains.
  * Added a session command which offers a JSON-based API for interaction with
    other tools via stdin/ stdout.
- Update the license tag.
* Sat Dec  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.14.1
  * Qt support: Fix static builds with Qt >= 5.13.1.
* Thu Oct 10 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.14.0. Check the changes-1.14.0.md file for the complete changelog.
  * Language: The `PathProbe` item was extended to support looking for
    multiple files and filtering candidate files.
  * Qt Support: Added the `Qt.android_support.extraLibs` property.
  * Other: The `pkgconfig` module now has a `sysroot` property.
  * Other: Added gRPC support to the `protobuf.cpp` module.
- Drop conditions for unsupported openSUSE versions.
* Fri Jul 12 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.13.1
  * Qt support: Plugins are no longer linked into static libraries when building against
    a static Qt (QBS-1441).
  * Qt support: Fixed excessively long linker command lines (QBS-1441).
  * Qt support: Host libraries are now looked up at the right location (QBS-1445).
  * Qt support: Fixed failure to find Qt modules in Qt Creator when re-parsing a project that
    hasn't been built yet.
* Thu May  2 2019 Christophe Giboudeaux <christophe@krop.fr>
- Change the license tag. qbs contains files licensed under
  GPL-3.0-only with some Qt exceptions.
* Sat Apr 20 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.13.0
  * Added a lot more documentation.
  * Introduced module providers.
  * The `Depends` item now falls back to `pkg-config` to locate dependencies
    whose names do not correspond to a qbs module.
  * Added the concept of job pools for limiting concurrent execution of commands
    by type.
  * Added support for rules without output artifacts.
  * Added `atEnd` function to the `Process` service.
  * Added `canonicalPath` function to the `FileInfo` service.
  * Removed the need to add "import qbs" at the head of project files.
  * The `Application`, `DynamicLibrary` and `StaticLibrary` items now have
    properties for more convenient installation of target binaries.
  * Added recursive dependency scanning of GNU ld linkerscripts.
  * Added new `cpp` property `linkerVariant` to force use of `gold`, `bfd` or
    `lld`.
  * It is no longer required to call `setup-qt` before building Qt projects.
  * Introduced the property `Qt.core.enableBigResources` for the creation of
    "big" Qt resources.
  * Static builds now pull in the default set of plugins as specified by Qt, and
    the user can specify the set of plugins by type.
  * Files can be explicitly tagged as mocable now.
  * Added `protobuf` support for C++ and Objective-C.
  * Introduced the `texttemplate` module, a facility similar to qmake's
    `SUBSTITUTES` feature.
  * The `AndroidApk` item was deprecated, a normal `Application` item can be
    used instead.
  * Building Qt apps is properly supported now, by making use of the
    `androiddeployqt` tool.
  * Introduced the `autotest` module.
* Mon Oct 22 2018 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.12.1:
  * Lifted the restriction that the -march option cannot appear in cpp.*Flags
  * All required header files get installed now
  * Fixed rpaths not ending up on the command line under certain circumstances
  * Fixed possible crash when scanning qrc files
  * Fixed spurious re-building of .pc and .qbs module files.
  * Fixed possible crash on storing a build graph after re-resolving.
  * Fixed possible assertion on input artifacts with alwaysUpdated == false.
* Fri Jul 20 2018 kai.koehne@qt.io
  Update to upstream version qbs 1.12.0
  Overview
  * Support for generating interface files for qbs and pkgconfig
  * Support for generating Makefiles (for debugging purposes)
  * System level settings got introduced
  Language Additions
  * New Exporter.qbs module to create a Qbs module from a product
  * New Exporter.pkgconfig module to generate .pc files
  * New varlist property type
  * New FileInfo.suffix and FileInfo.completeSuffix
  * explicitlyDependsOn property does no longer match artifacts
    from dependencies. Use the new
    explicitlyDependsOnFromDependencies property for that.
  * exclusiveAuxiliaryInputs got renamed to excludedInputs.
  * cLanguageVersion and cxxLanguageVersion are now arrays.
  * AutotestRunner has new property auxiliaryInputs.
  Command Line
  * qbs-config --system to write system wide settings
* Wed Apr  4 2018 kai.koehne@qt.io
  Update to upstream version qbs 1.11.0
  Language Additions
  * New qbs.targetPlatform, qbs.toolchainType properties
  * Modules can now declare their target artifacts with
    the new filesAreTargets property of the Group item
  * New BinaryFile service for reading and writing text files
  * New cpp.rpathOrigin, cpp.driverLinkerFlags properties
  * Support for "C++17" as cpp.cxxLanguageVersion
  Command Line
  * New way to specify configuration names with config key:
    $ qbs config:debug config:release
  * 'qbs run' now considers an executable's library dependencies
  * The qbs-qmltypes tool got replaced by a once generated
    qmltypes file.
  Removed 0001-Remove-top-level-include-path.patch, which is now
  included upstream.
* Thu Mar  8 2018 kai.koehne@qt.io
  Initial import of qbs 1.10.1
